==> 2.1.2-dev.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraPushBroadcastReceiver.java <==
package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import com.netmera.NetmeraPushBroadcastReceiver;
import com.netmera.NetmeraPushObject;

import io.flutter.FlutterInjector;

/**
 * Copyright (c) 2019 Inomera Research.
 *
 * @author Burak Soykal
 */
public class FNetmeraPushBroadcastReceiver extends NetmeraPushBroadcastReceiver {

    private static final String TAG = "Netmera Android";

    public static final String ON_PUSH_REGISTER = "onPushRegister";
    public static final String ON_PUSH_RECEIVE = "onPushReceive";
    public static final String ON_PUSH_OPEN = "onPushOpen";
    public static final String ON_PUSH_DISMISS = "onPushDismiss";
    public static final String ON_PUSH_BUTTON_CLICKED = "onPushButtonClicked";

    @Override
    protected void onPushRegister(Context context, String gcmSenderId, String pushToken) {
        Bundle bundle = new Bundle();
        bundle.putString("gcmSenderId", gcmSenderId);
        bundle.putString("pushToken", pushToken);
        sendMessage(context, ON_PUSH_REGISTER, bundle);
    }

    @Override
    protected void onPushReceive(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_RECEIVE, bundle);
    }

    @Override
    protected void onPushOpen(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_OPEN, bundle);
    }

    @Override
    protected void onPushDismiss(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_DISMISS, bundle);
    }

    @Override
    protected void onPushButtonClicked(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_BUTTON_CLICKED, bundle);
    }

    private void sendMessage(Context context, String action, Bundle bundle) {
        FlutterInjector.instance().flutterLoader().ensureInitializationComplete(context, null);
        Intent intent = new Intent(action);
        intent.putExtras(bundle);
        FNetmeraWorker.createAndStart(context, intent);
    }
}

==> 2.1.4-dev.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraPushBroadcastReceiver.java <==
package com.netmera.netmera_flutter_sdk;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import com.netmera.NetmeraPushObject;
import com.netmera.callbacks.NMPushActionCallbacks;

import io.flutter.FlutterInjector;

/**
 * Copyright (c) 2019 Inomera Research.
 *
 * @author Burak Soykal
 */
public class FNetmeraPushBroadcastReceiver implements NMPushActionCallbacks {

    private static final String TAG = "Netmera Android";

    public static final String ON_PUSH_REGISTER = "onPushRegister";
    public static final String ON_PUSH_RECEIVE = "onPushReceive";
    public static final String ON_PUSH_OPEN = "onPushOpen";
    public static final String ON_PUSH_DISMISS = "onPushDismiss";
    public static final String ON_PUSH_BUTTON_CLICKED = "onPushButtonClicked";

    @Override
    public void onPushRegister(Context context, String gcmSenderId, String pushToken) {
        Bundle bundle = new Bundle();
        bundle.putString("gcmSenderId", gcmSenderId);
        bundle.putString("pushToken", pushToken);
        sendMessage(context, ON_PUSH_REGISTER, bundle);
    }

    @Override
    public void onPushReceive(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_RECEIVE, bundle);
    }

    @Override
    public void onPushOpen(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_OPEN, bundle);
    }

    @Override
    public void onPushDismiss(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_DISMISS, bundle);
    }

    @Override
    public void onPushButtonClicked(Context context, Bundle bundle, NetmeraPushObject netmeraPushObject) {
        sendMessage(context, ON_PUSH_BUTTON_CLICKED, bundle);
    }

    private void sendMessage(Context context, String action, Bundle bundle) {
        FlutterInjector.instance().flutterLoader().ensureInitializationComplete(context, null);
        Intent intent = new Intent(action);
        intent.putExtras(bundle);
        FNetmeraWorker.createAndStart(context, intent);
    }
}
